==> bgp-bmp-api-0.13.2-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/params/xml/ns/yang/bmp/message/rev200120/mirror/TlvsBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.mirror;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.mirror.information.tlv.MirrorInformationTlv;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.mirror.pdu.tlvs.PduOpenTlv;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.mirror.pdu.tlvs.PduUpdateTlv;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link TlvsBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     TlvsBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new TlvsBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of TlvsBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see TlvsBuilder
 * @see Builder
 *
 */
public class TlvsBuilder implements Builder<Tlvs> {

    private MirrorInformationTlv _mirrorInformationTlv;
    private PduOpenTlv _pduOpenTlv;
    private PduUpdateTlv _pduUpdateTlv;


    Map<Class<? extends Augmentation<Tlvs>>, Augmentation<Tlvs>> augmentation = Collections.emptyMap();

    public TlvsBuilder() {
    }
    public TlvsBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.MirrorTlvs arg) {
        this._mirrorInformationTlv = arg.getMirrorInformationTlv();
        this._pduUpdateTlv = arg.getPduUpdateTlv();
        this._pduOpenTlv = arg.getPduOpenTlv();
    }
    public TlvsBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.MirrorInformationTlv arg) {
        this._mirrorInformationTlv = arg.getMirrorInformationTlv();
    }
    public TlvsBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.MirrorPduTlvs arg) {
        this._pduUpdateTlv = arg.getPduUpdateTlv();
        this._pduOpenTlv = arg.getPduOpenTlv();
    }

    public TlvsBuilder(Tlvs base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<Tlvs>>, Augmentation<Tlvs>> aug =((AugmentationHolder<Tlvs>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._mirrorInformationTlv = base.getMirrorInformationTlv();
        this._pduOpenTlv = base.getPduOpenTlv();
        this._pduUpdateTlv = base.getPduUpdateTlv();
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.MirrorTlvs</li>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.MirrorPduTlvs</li>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.MirrorInformationTlv</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.MirrorTlvs) {
            isValidArg = true;
        }
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.MirrorPduTlvs) {
            this._pduUpdateTlv = ((org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.MirrorPduTlvs)arg).getPduUpdateTlv();
            this._pduOpenTlv = ((org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.MirrorPduTlvs)arg).getPduOpenTlv();
            isValidArg = true;
        }
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.MirrorInformationTlv) {
            this._mirrorInformationTlv = ((org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.MirrorInformationTlv)arg).getMirrorInformationTlv();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.MirrorTlvs, org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.MirrorPduTlvs, org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.MirrorInformationTlv]");
    }

    public MirrorInformationTlv getMirrorInformationTlv() {
        return _mirrorInformationTlv;
    }
    
    public PduOpenTlv getPduOpenTlv() {
        return _pduOpenTlv;
    }
    
    public PduUpdateTlv getPduUpdateTlv() {
        return _pduUpdateTlv;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<Tlvs>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public TlvsBuilder setMirrorInformationTlv(final MirrorInformationTlv value) {
        this._mirrorInformationTlv = value;
        return this;
    }
    
    public TlvsBuilder setPduOpenTlv(final PduOpenTlv value) {
        this._pduOpenTlv = value;
        return this;
    }
    
    public TlvsBuilder setPduUpdateTlv(final PduUpdateTlv value) {
        this._pduUpdateTlv = value;
        return this;
    }
    
    public TlvsBuilder addAugmentation(Class<? extends Augmentation<Tlvs>> augmentationType, Augmentation<Tlvs> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public TlvsBuilder removeAugmentation(Class<? extends Augmentation<Tlvs>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public Tlvs build() {
        return new TlvsImpl(this);
    }

    private static final class TlvsImpl
        extends AbstractAugmentable<Tlvs>
        implements Tlvs {
    
        private final MirrorInformationTlv _mirrorInformationTlv;
        private final PduOpenTlv _pduOpenTlv;
        private final PduUpdateTlv _pduUpdateTlv;
    
        TlvsImpl(TlvsBuilder base) {
            super(base.augmentation);
            this._mirrorInformationTlv = base.getMirrorInformationTlv();
            this._pduOpenTlv = base.getPduOpenTlv();
            this._pduUpdateTlv = base.getPduUpdateTlv();
        }
    
        @Override
        public MirrorInformationTlv getMirrorInformationTlv() {
            return _mirrorInformationTlv;
        }
        
        @Override
        public PduOpenTlv getPduOpenTlv() {
            return _pduOpenTlv;
        }
        
        @Override
        public PduUpdateTlv getPduUpdateTlv() {
            return _pduUpdateTlv;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_mirrorInformationTlv);
            result = prime * result + Objects.hashCode(_pduOpenTlv);
            result = prime * result + Objects.hashCode(_pduUpdateTlv);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!Tlvs.class.equals(((DataObject)obj).implementedInterface())) {
                return false;
            }
            Tlvs other = (Tlvs)obj;
            if (!Objects.equals(_mirrorInformationTlv, other.getMirrorInformationTlv())) {
                return false;
            }
            if (!Objects.equals(_pduOpenTlv, other.getPduOpenTlv())) {
                return false;
            }
            if (!Objects.equals(_pduUpdateTlv, other.getPduUpdateTlv())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                TlvsImpl otherImpl = (TlvsImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<Tlvs>>, Augmentation<Tlvs>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("Tlvs");
            CodeHelpers.appendValue(helper, "_mirrorInformationTlv", _mirrorInformationTlv);
            CodeHelpers.appendValue(helper, "_pduOpenTlv", _pduOpenTlv);
            CodeHelpers.appendValue(helper, "_pduUpdateTlv", _pduUpdateTlv);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}

==> bgp-bmp-api-0.16.0-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/params/xml/ns/yang/bmp/message/rev200120/mirror/TlvsBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.mirror;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import javax.annotation.processing.Generated;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.MirrorPduTlvs;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.MirrorTlvs;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.mirror.information.tlv.MirrorInformationTlv;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.mirror.pdu.tlvs.PduOpenTlv;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.mirror.pdu.tlvs.PduUpdateTlv;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link TlvsBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     TlvsBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new TlvsBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of TlvsBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see TlvsBuilder
 * @see Builder
 *
 */
@Generated("mdsal-binding-generator")
public class TlvsBuilder implements Builder<Tlvs> {

    private MirrorInformationTlv _mirrorInformationTlv;
    private PduOpenTlv _pduOpenTlv;
    private PduUpdateTlv _pduUpdateTlv;


    Map<Class<? extends Augmentation<Tlvs>>, Augmentation<Tlvs>> augmentation = Collections.emptyMap();

    public TlvsBuilder() {
    }
    
    
    
    public TlvsBuilder(MirrorTlvs arg) {
        this._mirrorInformationTlv = arg.getMirrorInformationTlv();
        this._pduUpdateTlv = arg.getPduUpdateTlv();
        this._pduOpenTlv = arg.getPduOpenTlv();
    }
    public TlvsBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.MirrorInformationTlv arg) {
        this._mirrorInformationTlv = arg.getMirrorInformationTlv();
    }
    public TlvsBuilder(MirrorPduTlvs arg) {
        this._pduUpdateTlv = arg.getPduUpdateTlv();
        this._pduOpenTlv = arg.getPduOpenTlv();
    }

    public TlvsBuilder(Tlvs base) {
        Map<Class<? extends Augmentation<Tlvs>>, Augmentation<Tlvs>> aug = base.augmentations();
        if (!aug.isEmpty()) {
            this.augmentation = new HashMap<>(aug);
        }
        this._mirrorInformationTlv = base.getMirrorInformationTlv();
        this._pduOpenTlv = base.getPduOpenTlv();
        this._pduUpdateTlv = base.getPduUpdateTlv();
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>MirrorTlvs</li>
     * <li>MirrorPduTlvs</li>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.MirrorInformationTlv</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types or has property with incompatible value
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof MirrorTlvs) {
            isValidArg = true;
        }
        if (arg instanceof MirrorPduTlvs) {
            this._pduUpdateTlv = ((MirrorPduTlvs)arg).getPduUpdateTlv();
            this._pduOpenTlv = ((MirrorPduTlvs)arg).getPduOpenTlv();
            isValidArg = true;
        }
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.MirrorInformationTlv) {
            this._mirrorInformationTlv = ((org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.MirrorInformationTlv)arg).getMirrorInformationTlv();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[MirrorTlvs, MirrorPduTlvs, org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.MirrorInformationTlv]");
    }

    public MirrorInformationTlv getMirrorInformationTlv() {
        return _mirrorInformationTlv;
    }
    
    public PduOpenTlv getPduOpenTlv() {
        return _pduOpenTlv;
    }
    
    public PduUpdateTlv getPduUpdateTlv() {
        return _pduUpdateTlv;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<Tlvs>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(Objects.requireNonNull(augmentationType));
    }

    
    public TlvsBuilder setMirrorInformationTlv(final MirrorInformationTlv value) {
        this._mirrorInformationTlv = value;
        return this;
    }
    
    public TlvsBuilder setPduOpenTlv(final PduOpenTlv value) {
        this._pduOpenTlv = value;
        return this;
    }
    
    public TlvsBuilder setPduUpdateTlv(final PduUpdateTlv value) {
        this._pduUpdateTlv = value;
        return this;
    }
    
    /**
      * Add an augmentation to this builder's product.
      *
      * @param augmentation augmentation to be added
      * @return this builder
      * @throws NullPointerException if {@code augmentation} is null
      */
    public TlvsBuilder addAugmentation(Augmentation<Tlvs> augmentation) {
        Class<? extends Augmentation<Tlvs>> augmentationType = augmentation.implementedInterface();
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentation);
        return this;
    }
    
    /**
      * Remove an augmentation from this builder's product. If this builder does not track such an augmentation
      * type, this method does nothing.
      *
      * @param augmentationType augmentation type to be removed
      * @return this builder
      */
    public TlvsBuilder removeAugmentation(Class<? extends Augmentation<Tlvs>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public Tlvs build() {
        return new TlvsImpl(this);
    }

    private static final class TlvsImpl
        extends AbstractAugmentable<Tlvs>
        implements Tlvs {
    
        private final MirrorInformationTlv _mirrorInformationTlv;
        private final PduOpenTlv _pduOpenTlv;
        private final PduUpdateTlv _pduUpdateTlv;
    
        TlvsImpl(TlvsBuilder base) {
            super(base.augmentation);
            this._mirrorInformationTlv = base.getMirrorInformationTlv();
            this._pduOpenTlv = base.getPduOpenTlv();
            this._pduUpdateTlv = base.getPduUpdateTlv();
        }
    
        @Override
        public MirrorInformationTlv getMirrorInformationTlv() {
            return _mirrorInformationTlv;
        }
        
        @Override
        public PduOpenTlv getPduOpenTlv() {
            return _pduOpenTlv;
        }
        
        @Override
        public PduUpdateTlv getPduUpdateTlv() {
            return _pduUpdateTlv;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int result = Tlvs.bindingHashCode(this);
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            return Tlvs.bindingEquals(this, obj);
        }
    
        @Override
        public String toString() {
            return Tlvs.bindingToString(this);
        }
    }
}
